/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.alarm.model;

import com.nifty.cloud.sdk.annotation.Query;

/**
 * RuleActivities情報クラス。<br />
 * このクラスはRuleActivities情報を格納します。
 */
public class RuleActivities {

    /** 監視ルール名 */
    private String ruleName;

    /** 機能名 */
    private String functionName;

    /** 監視項目 */
    private String dataType;

    /** 履歴取得開始日付 */
    private String fromDate;

    /** 履歴取得終了日付 */
    private String toDate;

    /**
     * 監視ルール名を取得します。
     *
     * @return 監視ルール名
     */
    @Query(name = "RuleName")
    public String getRuleName() {
        return ruleName;
    }

    /**
     * 監視ルール名を設定します。
     *
     * @param ruleName
     *            監視ルール名
     */
    public void setRuleName(String ruleName) {
        this.ruleName = ruleName;
    }

    /**
     * 監視ルール名を設定し、自オブジェクトを返します。
     *
     * @param ruleName
     *            監視ルール名
     * @return 自オブジェクト
     */
    public RuleActivities withRuleName(String ruleName) {
        setRuleName(ruleName);
        return this;
    }

    /**
     * 機能名を取得します。
     *
     * @return 機能名
     */
    @Query(name = "FunctionName")
    public String getFunctionName() {
        return functionName;
    }

    /**
     * 機能名を設定します。
     *
     * @param functionName
     *            機能名
     */
    public void setFunctionName(String functionName) {
        this.functionName = functionName;
    }

    /**
     * 機能名を設定し、自オブジェクトを返します。
     *
     * @param functionName
     *            機能名
     * @return 自オブジェクト
     */
    public RuleActivities withFunctionName(String functionName) {
        setFunctionName(functionName);
        return this;
    }

    /**
     * 監視項目を取得します。
     *
     * @return 監視項目
     */
    @Query(name = "DataType")
    public String getDataType() {
        return dataType;
    }

    /**
     * 監視項目を設定します。
     *
     * @param dataType
     *            監視項目
     */
    public void setDataType(String dataType) {
        this.dataType = dataType;
    }

    /**
     * 監視項目を設定し、自オブジェクトを返します。
     *
     * @param dataType
     *            監視項目
     * @return 自オブジェクト
     */
    public RuleActivities withDataType(String dataType) {
        setDataType(dataType);
        return this;
    }

    /**
     * 履歴取得開始日付を取得します。
     *
     * @return 履歴取得開始日付
     */
    @Query(name = "FromDate")
    public String getFromDate() {
        return fromDate;
    }

    /**
     * 履歴取得開始日付を設定します。
     *
     * @param fromDate
     *            履歴取得開始日付
     */
    public void setFromDate(String fromDate) {
        this.fromDate = fromDate;
    }

    /**
     * 履歴取得開始日付を設定し、自オブジェクトを返します。
     *
     * @param fromDate
     *            履歴取得開始日付
     * @return 自オブジェクト
     */
    public RuleActivities withFromDate(String fromDate) {
        setFromDate(fromDate);
        return this;
    }

    /**
     * 履歴取得終了日付を取得します。
     *
     * @return 履歴取得終了日付
     */
    @Query(name = "ToDate")
    public String getToDate() {
        return toDate;
    }

    /**
     * 履歴取得終了日付を設定します。
     *
     * @param toDate
     *            履歴取得終了日付
     */
    public void setToDate(String toDate) {
        this.toDate = toDate;
    }

    /**
     * 履歴取得終了日付を設定し、自オブジェクトを返します。
     *
     * @param toDate
     *            履歴取得終了日付
     * @return 自オブジェクト
     */
    public RuleActivities withToDate(String toDate) {
        setToDate(toDate);
        return this;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder();
        builder.append("[ruleName=");
        builder.append(ruleName);
        builder.append(", functionName=");
        builder.append(functionName);
        builder.append(", fromDate=");
        builder.append(fromDate);
        builder.append(", toDate=");
        builder.append(toDate);
        builder.append("]");
        return builder.toString();
    }
}