/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.autoscale.model.transform;

import java.util.ArrayList;
import java.util.List;

import com.nifty.cloud.sdk.autoscale.model.DDay;
import com.nifty.cloud.sdk.autoscale.model.Day;
import com.nifty.cloud.sdk.autoscale.model.Month;
import com.nifty.cloud.sdk.autoscale.model.ScalingSchedule;
import com.nifty.cloud.sdk.autoscale.model.TimeZone;
import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;

/**
 * ScheduleSet変換クラス。<br />
 * このクラスはレスポンスXMLのscheduleSetの要素からScheduleSetクラスを生成します。
 */
public class ScheduleSetConverter implements Converter {

    private static final String ELEMENT_ITEM = "item";

    private static final String ELEMENT_TIME_ZONE = "timeZone";
    private static final String ELEMENT_DAY = "day";
    private static final String ELEMENT_DDAY = "dDay";
    private static final String ELEMENT_MONTH = "month";

    private static final String ELEMENT_STARTING_TIMEZONE = "startingTimeZone";
    private static final String ELEMENT_ENDING_TIMEZONE = "endingTimeZone";

    private static final String ELEMENT_SET_SUNDAY = "setSunday";
    private static final String ELEMENT_SET_MONDAY = "setMonday";
    private static final String ELEMENT_SET_TUESDAY = "setTuesday";
    private static final String ELEMENT_SET_WEDNESDAY = "setWednesday";
    private static final String ELEMENT_SET_THURSDAY = "setThursday";
    private static final String ELEMENT_SET_FRIDAY = "setFriday";
    private static final String ELEMENT_SET_SATURDAY = "setSaturday";

    private static final String ELEMENT_STARTING_DDAY = "startingDDay";
    private static final String ELEMENT_ENDING_DDAY = "endingDDay";

    private static final String ELEMENT_STARTING_MONTH = "startingMonth";
    private static final String ELEMENT_ENDING_MONTH = "endingMonth";

    /**
     * 変換可能なクラスか判定します。
     *
     * @param type
     *            クラス
     * @return 変換可能な場合true, 変換不可能な場合false
     *
     * @see com.thoughtworks.xstream.converters.Converter#canConvert(Class)
     */
    @Override
    @SuppressWarnings("rawtypes")
    public boolean canConvert(Class type) {
        return type == ScalingSchedule.class;
    }

    @Override
    public void marshal(Object source, HierarchicalStreamWriter writer,
        MarshallingContext context) {
        // 処理無し
    }

    @Override
    public Object unmarshal(HierarchicalStreamReader reader, UnmarshallingContext context) {

        List<ScalingSchedule> list = new ArrayList<ScalingSchedule>();

        ScalingSchedule schedule = null;
        TimeZone timezone = null;
        Day day = null;
        DDay dDay = null;
        Month month = null;

        String name = null;

        while (reader.hasMoreChildren()) {

            schedule = new ScalingSchedule();

            timezone = new TimeZone();
            day = new Day();
            dDay = new DDay();
            month = new Month();

            reader.moveDown();

            while (reader.hasMoreChildren()) {

                name = reader.getNodeName();

                if (name.equals(ELEMENT_ITEM)) {

                    reader.moveDown();

                    name = reader.getNodeName();

                    if (name.equals(ELEMENT_TIME_ZONE)) {

                        while (reader.hasMoreChildren()) {

                            reader.moveDown();

                            name = reader.getNodeName();

                            if (name.equals(ELEMENT_STARTING_TIMEZONE)) {
                                timezone.setStartingTimeZone(reader.getValue());
                            } else if (name.equals(ELEMENT_ENDING_TIMEZONE)) {
                                timezone.setEndingTimeZone(reader.getValue());
                            }

                            reader.moveUp();

                        }

                    } else if (name.equals(ELEMENT_DAY)) {

                        while (reader.hasMoreChildren()) {

                            reader.moveDown();

                            name = reader.getNodeName();

                            if (name.equals(ELEMENT_SET_SUNDAY)) {
                                day.setSunday(reader.getValue());
                            } else if (name.equals(ELEMENT_SET_MONDAY)) {
                                day.setMonday(reader.getValue());
                            } else if (name.equals(ELEMENT_SET_TUESDAY)) {
                                day.setTuesday(reader.getValue());
                            } else if (name.equals(ELEMENT_SET_WEDNESDAY)) {
                                day.setWednesday(reader.getValue());
                            } else if (name.equals(ELEMENT_SET_THURSDAY)) {
                                day.setThursday(reader.getValue());
                            } else if (name.equals(ELEMENT_SET_FRIDAY)) {
                                day.setFriday(reader.getValue());
                            } else if (name.equals(ELEMENT_SET_SATURDAY)) {
                                day.setSaturday(reader.getValue());
                            }

                            reader.moveUp();

                        }

                    } else if (name.equals(ELEMENT_DDAY)) {

                        while (reader.hasMoreChildren()) {

                            reader.moveDown();

                            name = reader.getNodeName();

                            if (name.equals(ELEMENT_STARTING_DDAY)) {
                                dDay.setStartingDDay(reader.getValue());
                            } else if (name.equals(ELEMENT_ENDING_DDAY)) {
                                dDay.setEndingDDay(reader.getValue());
                            }

                            reader.moveUp();

                        }

                    } else if (name.equals(ELEMENT_MONTH)) {

                        while (reader.hasMoreChildren()) {

                            reader.moveDown();

                            name = reader.getNodeName();

                            if (name.equals(ELEMENT_STARTING_MONTH)) {
                                month.setStartingMonth(reader.getValue());
                            } else if (name.equals(ELEMENT_ENDING_MONTH)) {
                                month.setEndingMonth(reader.getValue());
                            }

                            reader.moveUp();

                        }

                    }

                }

                reader.moveUp();

            }

            schedule.setTimeZone(timezone);
            schedule.setDay(day);
            schedule.setDDay(dDay);
            schedule.setMonth(month);

            list.add(schedule);

            reader.moveUp();

        }

        return list;
    }

}
