/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.dhcp.model;

import com.nifty.cloud.sdk.Result;
import com.nifty.cloud.sdk.dhcp.model.transform.CreateDhcpOptionsResultConverter;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamConverter;

/**
 * CreateDhcpOptions処理結果クラス。<br />
 * このクラスはCreateDhcpOptionsのレスポンスを格納します。
 */
@XStreamAlias("CreateDhcpOptionsResponse")
@XStreamConverter(CreateDhcpOptionsResultConverter.class)
public class CreateDhcpOptionsResult extends Result {

	/** リクエスト識別子 */
	private String requestId;

	/** DHCPオプション情報 */
	private DhcpOptions dhcpOptions;

	/**
	 * リクエスト識別子を取得します。
	 *
	 * @return リクエスト識別子
	 */
	public String getRequestId() {
		return requestId;
	}

	/**
	 * リクエスト識別子を設定します。
	 *
	 * @param requestId リクエスト識別子
	 */
	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	/**
	 * リクエスト識別子を設定し、自オブジェクトを返します。
	 *
	 * @param requestId リクエスト識別子
	 * @return 自オブジェクト
	 */
	public CreateDhcpOptionsResult withRequestId(String requestId) {
		setRequestId(requestId);
		return this;
	}

	/**
	 * DHCPオプション情報を取得します。
	 *
	 * @return DHCPオプション情報
	 */
	public DhcpOptions getDhcpOptions() {
		return dhcpOptions;
	}

	/**
	 * DHCPオプション情報を設定します。
	 *
	 * @param dhcpOptions DHCPオプション情報
	 */
	public void setDhcpOptions(DhcpOptions dhcpOptions) {
		this.dhcpOptions = dhcpOptions;
	}

	/**
	 * DHCPオプション情報を設定し、自オブジェクトを返します。
	 *
	 * @param dhcpOptions DHCPオプション情報
	 * @return 自オブジェクト
	 */
	public CreateDhcpOptionsResult withDhcpOptions(DhcpOptions dhcpOptions) {
		setDhcpOptions(dhcpOptions);
		return this;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("[requestId=");
		builder.append(requestId);
		builder.append(", dhcpOptions=");
		builder.append(dhcpOptions);
		builder.append("]");
		return builder.toString();
	}
}
