/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.disk.model;

import com.nifty.cloud.sdk.Request;
import com.nifty.cloud.sdk.annotation.Action;
import com.nifty.cloud.sdk.annotation.Query;

/**
 * ExtendVolumeSizeリクエストクラス。<br />
 * このクラスはExtendVolumeSizeへのリクエストを構築します。
 */
@Action("ExtendVolumeSize")
public class ExtendVolumeSizeRequest implements Request {

    /** ディスク名 */
    private String volumeId;

    /** 再起動オプション */
    private String niftyReboot;

    /**
     * デフォルトコンストラクタ。
     */
    public ExtendVolumeSizeRequest() {
    }

    /**
     * ディスク名、再起動オプションを指定し、ExtendVolumeSizeRequestを構築します。
     *
     * @param volumeId ディスク名
     * @param niftyReboot 再起動オプション
     */
    public ExtendVolumeSizeRequest(String volumeId, String niftyReboot) {
        this.volumeId = volumeId;
        this.niftyReboot = niftyReboot;
    }

    /**
     * ディスク名を取得します。
     *
     * @return ディスク名
     */
    @Query(name="VolumeId", require=true)
    public String getVolumeId() {
        return volumeId;
    }
    /**
     * ディスク名を設定します。
     *
     * @param volumeId ディスク名
     */
    public void setVolumeId(String volumeId) {
        this.volumeId = volumeId;
    }
    /**
     * ディスク名を設定し、自オブジェクトを返します。
     *
     * @param volumeId ディスク名
     * @return 自オブジェクト
     */
    public ExtendVolumeSizeRequest withVolumeId(String volumeId) {
        setVolumeId(volumeId);
        return this;
    }

    /**
     * 再起動オプションを取得します。
     *
     * @return 再起動オプション
     */
    @Query(name = "NiftyReboot")
    public String getNiftyReboot() {
        return niftyReboot;
    }

    /**
     * 再起動オプションを設定します。
     *
     * @param niftyReboot 再起動オプション
     */
    public void setNiftyReboot(String niftyReboot) {
        this.niftyReboot = niftyReboot;
    }

    /**
     * 再起動オプションを設定し、自オブジェクトを返します。
     *
     * @param niftyReboot 再起動オプション
     * @return 自オブジェクト
     */
    public ExtendVolumeSizeRequest withNiftyReboot(String niftyReboot) {
        setNiftyReboot(niftyReboot);
        return this;
    }


    /* (non-Javadoc)
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder();
        builder.append("[volumeId=");
        builder.append(volumeId);
        builder.append(", niftyReboot=");
        builder.append(niftyReboot);
        builder.append("]");
        return builder.toString();
    }
}
