/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.loadbalancer.model.transform;

import java.util.ArrayList;
import java.util.List;

import com.nifty.cloud.sdk.loadbalancer.model.SSLPolicySet;
import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;

/**
 * SSLPolicySet変換クラス。<br />
 * このクラスはレスポンスXMLのSSLPolicySetの要素からSSLPolicySetクラスを生成します。
 */
public class SSLPolicySetConverter implements Converter {

    private static final String ELEMENT_MEMBER = "member";
    private static final String ELEMENT_CIPHER = "Cipher";

    /**
     * 変換可能なクラスか判定します。
     *
     * @param type
     *            クラス
     * @return 変換可能な場合true, 変換不可能な場合false
     *
     * @see com.thoughtworks.xstream.converters.Converter#canConvert(Class)
     */
    @Override
    @SuppressWarnings("rawtypes")
    public boolean canConvert(Class type) {
        return type == SSLPolicySet.class;
    }

    @Override
    public void marshal(Object source, HierarchicalStreamWriter writer,
        MarshallingContext context) {
        // 処理無し
    }

    @Override
    public Object unmarshal(HierarchicalStreamReader reader, UnmarshallingContext context) {

        List<SSLPolicySet> list = new ArrayList<SSLPolicySet>();

        SSLPolicySet sslPolicySet = null;

        String name = null;

        while (reader.hasMoreChildren()) {

            sslPolicySet = new SSLPolicySet();

            reader.moveDown();

            while (reader.hasMoreChildren()) {

                name = reader.getNodeName();

                if (name.equals(ELEMENT_MEMBER)) {

                    reader.moveDown();

                    name = reader.getNodeName();

                    if (name.equals(ELEMENT_CIPHER)) {
                        sslPolicySet.setCipher(reader.getValue());
                    }

                }

                reader.moveUp();

            }

            reader.moveUp();

            list.add(sslPolicySet);

        }

        return list;

    }

}
