/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.privatelan.model;

/**
 * Routerクラス。<br />
 * このクラスはRouter情報を格納します。
 */
public class Router {

	/** ルーターユニークID */
	private String routerId;

	/** ルーター名 */
	private String routerName;

	/** デバイス番号 */
	private Integer deviceIndex;

	/** IPアドレス */
	private String ipAddress;

	/**
	 * ルーターユニークIDを取得します。
	 * @return ルーターユニークID
	 */
	public String getRouterId() {
	    return routerId;
	}
	/**
	 * ルーターユニークIDを設定します。
	 * @param routerId ルーターユニークID
	 */
	public void setRouterId(String routerId) {
	    this.routerId = routerId;
	}
	/**
	 * ルーターユニークIDを設定し、自オブジェクトを返します。
	 *
	 * @param routerId ルーターユニークID
	 * @return 自オブジェクト
	 */
	public Router withRouterId(String routerId) {
		setRouterId(routerId);
		return this;
	}

	/**
	 * ルーター名を取得します。
	 * @return ルーター名
	 */
	public String getRouterName() {
	    return routerName;
	}
	/**
	 * ルーター名を設定します。
	 * @param routerName ルーター名
	 */
	public void setRouterName(String routerName) {
	    this.routerName = routerName;
	}
	/**
	 * ルーター名を設定し、自オブジェクトを返します。
	 *
	 * @param routerName ルーター名
	 * @return 自オブジェクト
	 */
	public Router withRouterName(String routerName) {
		setRouterName(routerName);
		return this;
	}

	/**
	 * デバイス番号を取得します。
	 * @return デバイス番号
	 */
	public Integer getDeviceIndex() {
	    return deviceIndex;
	}
	/**
	 * デバイス番号を設定します。
	 * @param deviceIndex デバイス番号
	 */
	public void setDeviceIndex(Integer deviceIndex) {
	    this.deviceIndex = deviceIndex;
	}
	/**
	 * デバイス番号を設定し、自オブジェクトを返します。
	 *
	 * @param deviceIndex
	 * @return 自オブジェクト
	 */
	public Router withDeviceIndex(Integer deviceIndex) {
		setDeviceIndex(deviceIndex);
		return this;
	}

	/**
	 * IPアドレスを取得します。
	 * @return IPアドレス
	 */
	public String getIpAddress() {
	    return ipAddress;
	}
	/**
	 * IPアドレスを設定します。
	 * @param ipAddress IPアドレス
	 */
	public void setIpAddress(String ipAddress) {
	    this.ipAddress = ipAddress;
	}
	/**
	 * IPアドレスを設定し、自オブジェクトを返します。
	 *
	 * @param ipAddress IPアドレス
	 * @return 自オブジェクト
	 */
	public Router withIpAddress(String ipAddress) {
		setIpAddress(ipAddress);
		return this;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("[routerId=");
		builder.append(routerId);
		builder.append(", routerName=");
		builder.append(routerName);
		builder.append(", deviceIndex=");
		builder.append(deviceIndex);
		builder.append(", ipAddress=");
		builder.append(ipAddress);
		builder.append("]");
		return builder.toString();
	}
}
