/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.sample;

import static java.lang.System.*;

import com.nifty.cloud.sdk.ClientConfiguration;
import com.nifty.cloud.sdk.NiftyClientException;
import com.nifty.cloud.sdk.auth.BasicCredentials;
import com.nifty.cloud.sdk.auth.Credentials;
import com.nifty.cloud.sdk.multiloadbalancer.NiftyMultiLoadBalancerClient;
import com.nifty.cloud.sdk.multiloadbalancer.model.ExpectationMember;
import com.nifty.cloud.sdk.multiloadbalancer.model.NiftyConfigureElasticLoadBalancerHealthCheckRequest;
import com.nifty.cloud.sdk.multiloadbalancer.model.NiftyConfigureElasticLoadBalancerHealthCheckResult;

/**
 * NiftyConfigureElasticLoadBalancerHealthCheckサンプル
 *
 */
public class NiftyConfigureElasticLoadBalancerHealthCheckSample {

    /**
     * NiftyConfigureElasticLoadBalancerHealthCheckを実行するサンプルです。 必要なパラメーターを設定してから利用してください。
     *
     * @param args
     *            利用しない
     */
    public static void main(String[] args) {

        /************************************************************************
         * AccessKeyとSecretAccessKeyを設定します。 キーはNIFCLOUDのコントロールパネルから取得します。
         ***********************************************************************/
        String accessKey = "<Input Your AccessKey>";
        String secretKey = "<Input Your SecretAccessKey>";

        /************************************************************************
         * 指定されたAccessKeyとSecretAccessKeyから認証情報インスタンスを生成します。
         ***********************************************************************/
        Credentials credential = new BasicCredentials(accessKey, secretKey);

        /************************************************************************
         * クライアント設定情報インスタンスを生成します。 設定情報を変更する場合は値を設定します。 以下の項目について設定可能です。 - ユーザーエージェント - プロトコル -
         * プロキシサーバーアドレス - プロキシサーバーポート番号 - プロキシユーザー名 - プロキシパスワード - 最大リトライ回数 - 最大接続数 - TCPソケットタイムアウト秒数
         * - 接続タイムアウト秒数 - 送信バッファサイズ / 受信バッファサイズ - SignatureVersion - SignatureMethod HTTPメソッド
         ***********************************************************************/
        ClientConfiguration config = new ClientConfiguration();
        // config.setUserAgent("NIFCLOUD API Java SDK");
        // config.setProtocol(Protocol.HTTPS);
        // config.setProxyHost("proxy_host");
        // config.setProxyPort(0);
        // config.setProxyUsername("proxy_username");
        // config.setProxyPassword("proxy_password");
        // config.setMaxErrorRetry(3);
        // config.setMaxConnections(50);
        // config.setSocketTimeout(30);
        // config.setConnectionTimeout(30);
        // config.setSocketSendBufferSizeHint(0, 0);
        // config.setSignatureVersion(SignatureVersion.Version_2);
        // config.setSignatureMethod(SignatureMethod.HmacSHA256);
        // config.setRequestMethod("GET");

        /************************************************************************
         * 認証情報とクライアント設定情報からマルチロードバランサーカテゴリ クライアントを生成します。
         * 非同期実行を行う場合はNiftyMultiLoadBalancerAsyncClientクラスを指定します。
         ***********************************************************************/
        NiftyMultiLoadBalancerClient client = new NiftyMultiLoadBalancerClient(credential, config);

        /************************************************************************
         * 接続先URLを変更する場合は接続先を指定します。
         ***********************************************************************/
        // client.setEndpoint("endpoint_url");

        /************************************************************************
         * リクエストパラメーターを設定し、NiftyConfigureElasticLoadBalancerHealthCheckを実行します。
         ***********************************************************************/
        NiftyConfigureElasticLoadBalancerHealthCheckRequest request =
            new NiftyConfigureElasticLoadBalancerHealthCheckRequest();

        // request.setElasticLoadBalancerId("loadBalancerId");
        // request.setElasticLoadBalancerName("loadBalancerName");
        // request.setProtocol("https");
        // request.setElasticLoadBalancerPort(Integer.valueOf(8081));
        // request.setInstancePort(Integer.valueOf(8082));

        // List<HttpMember> list = new ArrayList<HttpMember>();

        // HttpMember member1 = new HttpMember();
        // member1.setHttpCode("2xx");

        // list.add(member1);

        // HttpMember member2 = new HttpMember();
        // member2.setHttpCode("3xx");

        // list.add(member2);

        // RequestExpectation exp = new RequestExpectation();
        // exp.setMember(list);

        // RequestHealthCheck check = new RequestHealthCheck();
        // check.setTarget("8081");
        // check.setInterval(Integer.valueOf(20));
        // check.setUnhealthyThreshold(Integer.valueOf(5));
        // check.setPath("path");
        // check.setExpectation(exp);

        // request.setHealthCheck(check);

        invokeNiftyConfigureElasticLoadBalancerHealthCheck(client, request);

    }

    /**
     * NiftyConfigureElasticLoadBalancerHealthCheck 実行サンプル 設定されたリクエストから
     * NiftyConfigureElasticLoadBalancerHealthCheck を実行し、実行結果を表示します。
     *
     * @param client
     *            クライアント
     * @param request
     *            リクエスト
     */
    public static void invokeNiftyConfigureElasticLoadBalancerHealthCheck(
        NiftyMultiLoadBalancerClient client,
        NiftyConfigureElasticLoadBalancerHealthCheckRequest request) {
        try {
            NiftyConfigureElasticLoadBalancerHealthCheckResult result =
                client.niftyConfigureElasticLoadBalancerHealthCheck(request);

            out.println("NiftyConfigureElasticLoadBalancerHealthCheck Action Response");
            out.println(
                "=============================================================================");

            if (result.getHealthCheck().getTarget() != null) {
                out.println("Target            :" + result.getHealthCheck().getTarget());
            }

            if (result.getHealthCheck().getTimeout() != null) {
                out.println("Interval          :" + result.getHealthCheck().getInterval());
            }

            if (result.getHealthCheck().getInterval() != null) {
                out.println("Timeout           :" + result.getHealthCheck().getTimeout());
            }

            if (result.getHealthCheck().getUnhealthyThreshold() != null) {
                out.println("UnhealthyThreshold:" + result.getHealthCheck().getUnhealthyThreshold());
            }

            if (result.getHealthCheck().getHealthyThreshold() != null) {
                out.println("HealthyThreshold  :" + result.getHealthCheck().getHealthyThreshold());
            }

            if (result.getHealthCheck().getPath() != null) {
                out.println("Path              :" + result.getHealthCheck().getPath());
            }

            for(ExpectationMember work : result.getHealthCheck().getExpectation().getMemberList()) {

                if (work.getHttpCode() != null) {
                    out.println("  HttpCode        :" + work.getHttpCode());
                }

            }


            out.println(
                "=============================================================================");

        } catch (NiftyClientException ex) {
            err.println("Message: " + ex.getMessage());
        }
    }
}
