/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.sample;

import static java.lang.System.*;

import com.nifty.cloud.sdk.ClientConfiguration;
import com.nifty.cloud.sdk.NiftyClientException;
import com.nifty.cloud.sdk.auth.BasicCredentials;
import com.nifty.cloud.sdk.auth.Credentials;
import com.nifty.cloud.sdk.multiloadbalancer.NiftyMultiLoadBalancerClient;
import com.nifty.cloud.sdk.multiloadbalancer.model.NiftyDescribeInstanceElasticLoadBalancerHealthRequest;
import com.nifty.cloud.sdk.multiloadbalancer.model.NiftyDescribeInstanceElasticLoadBalancerHealthResult;
import com.nifty.cloud.sdk.multiloadbalancer.model.ServerMember;

/**
 * NiftyDescribeInstanceElasticLoadBalancerHealthサンプル
 *
 */
public class NiftyDescribeInstanceElasticLoadBalancerHealthSample {

    /**
     * NiftyDescribeInstanceElasticLoadBalancerHealthを実行するサンプルです。 必要なパラメーターを設定してから利用してください。
     *
     * @param args
     *            利用しない
     */
    public static void main(String[] args) {

        /************************************************************************
         * AccessKeyとSecretAccessKeyを設定します。 キーはNIFCLOUDのコントロールパネルから取得します。
         ***********************************************************************/
        String accessKey = "<Input Your AccessKey>";
        String secretKey = "<Input Your SecretAccessKey>";

        /************************************************************************
         * 指定されたAccessKeyとSecretAccessKeyから認証情報インスタンスを生成します。
         ***********************************************************************/
        Credentials credential = new BasicCredentials(accessKey, secretKey);

        /************************************************************************
         * クライアント設定情報インスタンスを生成します。 設定情報を変更する場合は値を設定します。 以下の項目について設定可能です。 - ユーザーエージェント - プロトコル -
         * プロキシサーバーアドレス - プロキシサーバーポート番号 - プロキシユーザー名 - プロキシパスワード - 最大リトライ回数 - 最大接続数 - TCPソケットタイムアウト秒数
         * - 接続タイムアウト秒数 - 送信バッファサイズ / 受信バッファサイズ - SignatureVersion - SignatureMethod HTTPメソッド
         ***********************************************************************/
        ClientConfiguration config = new ClientConfiguration();
        // config.setUserAgent("NIFCLOUD API Java SDK");
        // config.setProtocol(Protocol.HTTPS);
        // config.setProxyHost("proxy_host");
        // config.setProxyPort(0);
        // config.setProxyUsername("proxy_username");
        // config.setProxyPassword("proxy_password");
        // config.setMaxErrorRetry(3);
        // config.setMaxConnections(50);
        // config.setSocketTimeout(30);
        // config.setConnectionTimeout(30);
        // config.setSocketSendBufferSizeHint(0, 0);
        // config.setSignatureVersion(SignatureVersion.Version_2);
        // config.setSignatureMethod(SignatureMethod.HmacSHA256);
        // config.setRequestMethod("GET");

        /************************************************************************
         * 認証情報とクライアント設定情報からセキュリティカテゴリ クライアントを生成します。
         * 非同期実行を行う場合はNiftyMultiLoadBalancerAsyncClientクラスを指定します。
         ***********************************************************************/
        NiftyMultiLoadBalancerClient client = new NiftyMultiLoadBalancerClient(credential, config);

        /************************************************************************
         * 接続先URLを変更する場合は接続先を指定します。
         ***********************************************************************/
        // client.setEndpoint("endpoint_url");

        /************************************************************************
         * リクエストパラメーターを設定し、NiftyDescribeInstanceElasticLoadBalancerHealthを実行します。
         ***********************************************************************/
        NiftyDescribeInstanceElasticLoadBalancerHealthRequest request =
            new NiftyDescribeInstanceElasticLoadBalancerHealthRequest();

//        request.setElasticLoadBalancerId("loadBalancerId");
//        request.setElasticLoadBalancerName("loadBalancerName");
//        request.setProtocol("https");
//        request.setElasticLoadBalancerPort(Integer.valueOf(8081));
//        request.setInstancePort(Integer.valueOf(8082));

//        List<ServerMember> list = new ArrayList<ServerMember>();

//        ServerMember member1 = new ServerMember();
//        member1.setInstanceId("instanceId1");
//        member1.setInstanceUniqueId("instanceUniqueId1");

//        list.add(member1);

//        ServerMember member2 = new ServerMember();
//        member2.setInstanceId("instanceId2");
//        member2.setInstanceUniqueId("instanceUniqueId2");

//        list.add(member2);

//        Instance instance = new Instance();
//        instance.setMemberList(list);

//        request.setInstances(instance);

        invokeNiftyDeregisterInstancesFromElasticLoadBalancer(client, request);

    }

    /**
     * NiftyDescribeInstanceElasticLoadBalancerHealth 実行サンプル 設定されたリクエストから
     * NiftyDescribeInstanceElasticLoadBalancerHealth を実行し、実行結果を表示します。
     *
     * @param client
     *            クライアント
     * @param request
     *            リクエスト
     */
    public static void invokeNiftyDeregisterInstancesFromElasticLoadBalancer(
        NiftyMultiLoadBalancerClient client,
        NiftyDescribeInstanceElasticLoadBalancerHealthRequest request) {
        try {
            NiftyDescribeInstanceElasticLoadBalancerHealthResult result =
                client.niftyDescribeInstanceElasticLoadBalancerHealth(request);

            out.println("NiftyDescribeInstanceElasticLoadBalancerHealth Action Response");
            out.println(
                "=============================================================================");

            for(ServerMember work : result.getInstance().getMember()) {
                
                if (work.getInstanceId() != null) {
                    out.println("InstanceId      :" + work.getInstanceId());
                }

                if (work.getInstanceUniqueId() != null) {
                    out.println(
                        "InstanceUniqueId:" + work.getInstanceUniqueId());
                }

                if (work.getState() != null) {
                    out.println("State           :" + work.getState());
                }
                
            }

            out.println(
                "=============================================================================");

        } catch (NiftyClientException ex) {
            err.println("Message: " + ex.getMessage());
        }
    }
}
