/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.sample;

import static java.lang.System.*;

import java.util.List;

import com.nifty.cloud.sdk.ClientConfiguration;
import com.nifty.cloud.sdk.NiftyClientException;
import com.nifty.cloud.sdk.auth.BasicCredentials;
import com.nifty.cloud.sdk.auth.Credentials;
import com.nifty.cloud.sdk.autoscale.NiftyAutoScaleClient;
import com.nifty.cloud.sdk.autoscale.model.LogSet;
import com.nifty.cloud.sdk.autoscale.model.NiftyDescribeScalingActivitiesRequest;
import com.nifty.cloud.sdk.autoscale.model.NiftyDescribeScalingActivitiesResult;

/**
 * NiftyDescribeScalingActivitiesサンプル
 *
 */
public class NiftyDescribeScalingActivitiesSample {

    /**
     * NiftyDescribeScalingActivitiesを実行するサンプルです。 必要なパラメーターを設定してから利用してください。
     *
     * @param args
     *            利用しない
     */
    public static void main(String[] args) {

        /************************************************************************
         * AccessKeyとSecretAccessKeyを設定します。 キーはNIFCLOUDのコントロールパネルから取得します。
         ***********************************************************************/
        String accessKey = "<Input Your AccessKey>";
        String secretKey = "<Input Your SecretAccessKey>";

        /************************************************************************
         * 指定されたAccessKeyとSecretAccessKeyから認証情報インスタンスを生成します。
         ***********************************************************************/
        Credentials credential = new BasicCredentials(accessKey, secretKey);

        /************************************************************************
         * クライアント設定情報インスタンスを生成します。 設定情報を変更する場合は値を設定します。 以下の項目について設定可能です。 - ユーザーエージェント - プロトコル -
         * プロキシサーバーアドレス - プロキシサーバーポート番号 - プロキシユーザー名 - プロキシパスワード - 最大リトライ回数 - 最大接続数 - TCPソケットタイムアウト秒数
         * - 接続タイムアウト秒数 - 送信バッファサイズ / 受信バッファサイズ - SignatureVersion - SignatureMethod HTTPメソッド
         ***********************************************************************/
        ClientConfiguration config = new ClientConfiguration();
        // config.setUserAgent("NIFCLOUD API Java SDK");
        // config.setProtocol(Protocol.HTTPS);
        // config.setProxyHost("proxy_host");
        // config.setProxyPort(0);
        // config.setProxyUsername("proxy_username");
        // config.setProxyPassword("proxy_password");
        // config.setMaxErrorRetry(3);
        // config.setMaxConnections(50);
        // config.setSocketTimeout(30);
        // config.setConnectionTimeout(30);
        // config.setSocketSendBufferSizeHint(0, 0);
        // config.setSignatureVersion(SignatureVersion.Version_2);
        // config.setSignatureMethod(SignatureMethod.HmacSHA256);
        // config.setRequestMethod("GET");

        /************************************************************************
         * 認証情報とクライアント設定情報からオートスケールカテゴリ クライアントを生成します。 非同期実行を行う場合はNiftyAutoScaleAsyncClientクラスを指定します。
         ***********************************************************************/
        NiftyAutoScaleClient client = new NiftyAutoScaleClient(credential, config);

        /************************************************************************
         * 接続先URLを変更する場合は接続先を指定します。
         ***********************************************************************/
        // client.setEndpoint("endpoint_url");

        /************************************************************************
         * リクエストパラメーターを設定し、NiftyDescribeScalingActivitiesを実行します。
         ***********************************************************************/
        NiftyDescribeScalingActivitiesRequest request = new NiftyDescribeScalingActivitiesRequest();

        // request.setAutoScalingGroupName("test");
        // request.setActivityDateFrom("20180110");
        // request.setActivityDateTo("20180120");

        // Range range = new Range();
        // range.setAll(Boolean.TRUE);
        // range.setStartNumber(Integer.valueOf(5));
        // range.setEndNumber(Integer.valueOf(10));

        // request.setRange(range);

        invokeNiftyDescribeAutoScalingGroups(client, request);

    }

    /**
     * NiftyDescribeScalingActivities 実行サンプル 設定されたリクエストから NiftyDescribeScalingActivities
     * を実行し、実行結果を表示します。
     *
     * @param client
     *            クライアント
     * @param request
     *            リクエスト
     */
    public static void invokeNiftyDescribeAutoScalingGroups(NiftyAutoScaleClient client,
        NiftyDescribeScalingActivitiesRequest request) {
        try {

            NiftyDescribeScalingActivitiesResult result =
                client.niftyDescribeScalingActivities(request);

            List<LogSet> list = result.getLogSet();

            out.println("NiftyDescribeScalingActivities Action Response");
            out.println(
                "=============================================================================");

            if (result.getRequestId() != null) {
                out.println("RequestId              :" + result.getRequestId());
            }

            if (result.getAutoScalingGroupName() != null) {
                out.println("AutoScalingGroupName   :" + result.getAutoScalingGroupName());
            }

            for (LogSet l : list) {

                if (l.getTime() != null) {
                    out.println("  Time                 :" + l.getTime());
                }

                if (l.getProcess() != null) {
                    out.println("  Process              :" + l.getProcess());
                }

                if (l.getDetails().getResource() != null) {
                    out.println("    Resource           :" + l.getDetails().getResource());
                }

                if (l.getDetails().getUpperThreshold() != null) {
                    out.println("    UpperThreshold     :" + l.getDetails().getUpperThreshold());
                }

                if (l.getDetails().getCurrentServersCount() != null) {
                    out.println(
                        "    CurrentServersCount:" + l.getDetails().getCurrentServersCount());
                }

                if (l.getDetails().getChangeInCapacity() != null) {
                    out.println("    ChangeInCapacity   :" + l.getDetails().getChangeInCapacity());
                }

                if (l.getDetails().getResourceValue() != null) {
                    out.println("    ResourceValue      :" + l.getDetails().getResourceValue());
                }

            }

            out.println(
                "=============================================================================");

        } catch (NiftyClientException ex) {
            err.println("Message: " + ex.getMessage());
        }
    }
}
