/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.separate.model;

/**
 * サーバーの情報クラス。<br />
 * このクラスはサーバーの情報を格納します。
 */
public class Instance {

    /** サーバー名 */
    private String instanceId;

    /** サーバーユニークID */
    private String instanceUniqueId;

    /**
     * サーバー名を取得します。
     *
     * @return サーバー名
     */
    public String getInstanceId() {
        return instanceId;
    }

    /**
     * サーバー名を設定します。
     *
     * @param instanceId
     *            サーバー名
     */
    public void setInstanceId(String instanceId) {
        this.instanceId = instanceId;
    }

    /**
     * サーバー名を設定し、自オブジェクトを返します。
     *
     * @param instanceId
     *            サーバー名
     * @return 自オブジェクト
     */
    public Instance withInstanceId(String instanceId) {
        setInstanceId(instanceId);
        return this;
    }

    /**
     * サーバーユニークIDを取得します。
     *
     * @return サーバーユニークID
     */
    public String getInstanceUniqueId() {
        return instanceUniqueId;
    }

    /**
     * サーバーユニークIDを設定します。
     *
     * @param instanceUniqueId
     *            サーバーユニークID
     */
    public void setInstanceUniqueId(String instanceUniqueId) {
        this.instanceUniqueId = instanceUniqueId;
    }

    /**
     * サーバーユニークIDを設定し、自オブジェクトを返します。
     *
     * @param instanceUniqueId
     *            サーバーユニークID
     * @return 自オブジェクト
     */
    public Instance withInstanceUniqueId(String instanceUniqueId) {
        setInstanceUniqueId(instanceUniqueId);
        return this;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder();
        builder.append("[instanceId=");
        builder.append(instanceId);
        builder.append(", instanceUniqueId=");
        builder.append(instanceUniqueId);
        builder.append("]");
        return builder.toString();
    }

}
