/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.vpngateway.model;

import com.nifty.cloud.sdk.Result;
import com.nifty.cloud.sdk.vpngateway.model.transform.CreateVpnGatewayResultConverter;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamConverter;

/**
 * CreateVpnGateway処理結果クラス。<br />
 * このクラスはCreateVpnGatewayのレスポンスを格納します。
 */
@XStreamAlias("CreateVpnGatewayResponse")
@XStreamConverter(CreateVpnGatewayResultConverter.class)
public class CreateVpnGatewayResult extends Result {

	/** リクエスト識別子 */
	private String requestId;

	/** VPNゲートウェイ情報 */
	private VpnGateway vpnGateway;

	/**
	 * リクエスト識別子を取得します。
	 *
	 * @return リクエスト識別子
	 */
	public String getRequestId() {
		return requestId;
	}

	/**
	 * リクエスト識別子を設定します。
	 *
	 * @param requestId リクエスト識別子
	 */
	public void setRequestId(String requestId) {
		this.requestId = requestId;
	}

	/**
	 * リクエスト識別子を設定し、自オブジェクトを返します。
	 *
	 * @param requestId リクエスト識別子
	 * @return 自オブジェクト
	 */
	public CreateVpnGatewayResult withRequestId(String requestId) {
		setRequestId(requestId);
		return this;
	}

	/**
	 * VPNゲートウェイ情報を取得します。
	 *
	 * @return VPNゲートウェイ情報
	 */
	public VpnGateway getVpnGateway() {
		return vpnGateway;
	}

	/**
	 * VPNゲートウェイ情報を設定します。
	 *
	 * @param vpnGateway VPNゲートウェイ情報
	 */
	public void setVpnGateway(VpnGateway vpnGateway) {
		this.vpnGateway = vpnGateway;
	}

	/**
	 * VPNゲートウェイ情報を設定し、自オブジェクトを返します。
	 *
	 * @param vpnGateway VPNゲートウェイ情報
	 * @return 自オブジェクト
	 */
	public CreateVpnGatewayResult withVpnGateway(VpnGateway vpnGateway) {
		setVpnGateway(vpnGateway);
		return this;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("[requestId=");
		builder.append(requestId);
		builder.append(", vpnGateway=");
		builder.append(vpnGateway);
		builder.append("]");
		return builder.toString();
	}
}
