/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.vpngateway.model;

import com.nifty.cloud.sdk.Request;
import com.nifty.cloud.sdk.annotation.Action;
import com.nifty.cloud.sdk.annotation.Query;

/**
 * NiftyReplaceRouteTableAssociationWithVpnGatewayリクエストクラス。<br />
 * このクラスはNiftyReplaceRouteTableAssociationWithVpnGatewayへのリクエストを構築します。
 *
 */
@Action("NiftyReplaceRouteTableAssociationWithVpnGateway")
public class NiftyReplaceRouteTableAssociationWithVpnGatewayRequest implements Request {

	/** ルートテーブル適用ID */
	private String associationId;

	/** ルートテーブルID */
	private String routeTableId;

	/** version up実施したのち、バックアップ状態を解除する事項への同意 */
	private Boolean agreement;

	/**
	 * デフォルトコンストラクタ。
	 */
	public NiftyReplaceRouteTableAssociationWithVpnGatewayRequest() {
	}

	/**
	 * ルートテーブル適用ID,ルートテーブルIDを指定し、NiftyReplaceRouteTableAssociationWithVpnGatewayRequestを構築します。
	 *
	 * @param associationId ルートテーブル適用ID
	 * @param routeTableId ルートテーブルID
	 */
	public NiftyReplaceRouteTableAssociationWithVpnGatewayRequest(String associationId, String routeTableId) {
		this.associationId = associationId;
		this.routeTableId = routeTableId;
	}

	/**
	 * ルートテーブル適用IDを取得します。
	 *
	 * @return ルートテーブル適用ID
	 */
	@Query(name="AssociationId", require=true)
	public String getAssociationId() {
		return associationId;
	}

	/**
	 * ルートテーブル適用IDを設定します。
	 *
	 * @param associationId ルートテーブル適用ID
	 */
	public void setAssociationId(String associationId) {
		this.associationId = associationId;
	}

	/**
	 * ルートテーブル適用IDを設定し、自オブジェクトを返します。
	 *
	 * @param associationId ルートテーブル適用ID
	 * @return 自オブジェクト
	 */
	public NiftyReplaceRouteTableAssociationWithVpnGatewayRequest withAssociationId(String associationId) {
		setAssociationId(associationId);
		return this;
	}

	/**
	 * ルートテーブルIDを取得します。
	 *
	 * @return ルートテーブルID
	 */
	@Query(name="RouteTableId", require=true)
	public String getRouteTableId() {
		return routeTableId;
	}

	/**
	 * ルートテーブルIDを設定します。
	 *
	 * @param routeTableId ルートテーブルID
	 */
	public void setRouteTableId(String routeTableId) {
		this.routeTableId = routeTableId;
	}

	/**
	 * ルートテーブルIDを設定し、自オブジェクトを返します。
	 *
	 * @param routeTableId ルートテーブルID
	 * @return 自オブジェクト
	 */
	public NiftyReplaceRouteTableAssociationWithVpnGatewayRequest withRouteTableId(String routeTableId) {
		setRouteTableId(routeTableId);
		return this;
	}

	/**
	 * version up実施したのち、バックアップ状態を解除する事項への同意を取得します。
	 *
	 * @return version up実施したのち、バックアップ状態を解除する事項への同意
	 */
	@Query(name="Agreement")
	public Boolean getAgreement() {
		return agreement;
	}

	/**
	 * version up実施したのち、バックアップ状態を解除する事項への同意を設定します。
	 *
	 * @param agreement version up実施したのち、バックアップ状態を解除する事項への同意
	 */
	public void setAgreement(Boolean agreement) {
		this.agreement = agreement;
	}

	/**
	 * version up実施したのち、バックアップ状態を解除する事項への同意を設定し、自オブジェクトを返します。
	 *
	 * @param agreement version up実施したのち、バックアップ状態を解除する事項への同意
	 * @return 自オブジェクト
	 */
	public NiftyReplaceRouteTableAssociationWithVpnGatewayRequest withAgreement(Boolean agreement) {
		setAgreement(agreement);
		return this;
	}

	/* (non-Javadoc)
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("[associationId=");
		builder.append(associationId);
		builder.append(", routeTableId=");
		builder.append(routeTableId);
		builder.append(", agreement=");
		builder.append(agreement);
		builder.append("]");
		return builder.toString();
	}
}
