/**
 * ******************************************************************************
 *  Copyright Fujitsu.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  You may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * *****************************************************************************
 *
 *  NIFCLOUD SDK for Java
 *
 */
package com.nifty.cloud.sdk.proxy.model.transform;

import com.nifty.cloud.sdk.proxy.model.NiftyCreateWebProxyResult;
import com.nifty.cloud.sdk.proxy.model.WebProxy;
import com.thoughtworks.xstream.converters.Converter;
import com.thoughtworks.xstream.converters.MarshallingContext;
import com.thoughtworks.xstream.converters.UnmarshallingContext;
import com.thoughtworks.xstream.io.HierarchicalStreamReader;
import com.thoughtworks.xstream.io.HierarchicalStreamWriter;

/**
 * NiftyCreateWebProxyResponseType変換クラス。<br />
 * このクラスはレスポンスXMLのNiftyCreateWebProxyResponse要素からNiftyCreateWebProxyResultクラスを生成します。
 */
public class NiftyCreateWebProxyResultConverter implements Converter {

	private static final String ELEMENT_REQUEST_ID = "requestId";
	private static final String ELEMENT_WEB_PROXY = "webProxy";

	/**
	 * 変換可能なクラスか判定します。
	 *
	 * @param clazz クラス
	 * @return 変換可能な場合true, 変換不可能な場合false
	 *
	 * @see com.thoughtworks.xstream.converters.Converter#canConvert(Class)
	 */
	@SuppressWarnings("rawtypes")
	@Override
	public boolean canConvert(Class clazz) {
		return clazz == NiftyCreateWebProxyResult.class;
	}

	/**
	 * {@literal
	 * NiftyCreateWebProxyResponseをNiftyCreateWebProxyResultクラスに変換します。}
	 *
	 * @param reader XML読込リーダ
	 * @param context
	 * @return {@literal NiftyCreateWebProxyResultオブジェクト}
	 *
	 * @see com.thoughtworks.xstream.converters.Converter#unmarshal(HierarchicalStreamReader, UnmarshallingContext)
	 */
	@Override
	public Object unmarshal(HierarchicalStreamReader reader, UnmarshallingContext context) {
		NiftyCreateWebProxyResult niftyCreateWebProxyResult = new NiftyCreateWebProxyResult();
		Converter webProxyConverter = new WebProxyConverter();

		String name = null;
		while (reader.hasMoreChildren()) {
			reader.moveDown();

			name = reader.getNodeName();
			if (name.equals(ELEMENT_REQUEST_ID)) {
				niftyCreateWebProxyResult.setRequestId(reader.getValue());
			} else if (name.equals(ELEMENT_WEB_PROXY)) {
				niftyCreateWebProxyResult.setWebProxy((WebProxy) webProxyConverter.unmarshal(reader, context));
			}

			reader.moveUp();
		}

		return niftyCreateWebProxyResult;
	}

	/**
	 * 未実装メソッド
	 */
	@Override
	public void marshal(Object paramObject,
			HierarchicalStreamWriter paramHierarchicalStreamWriter,
			MarshallingContext paramMarshallingContext) {
	}
}
